
# Under Construction 
This package is in the early development stage. Use at your own risk.

# What is it?
CoziePy is a Python package to retrieve, process, and visualize data collected witht the [Cozie Apple app](https://cozie-apple.app/). It aims to make the handling aof Cozie data easier.

# Where to get it?
TBD

# How to use it?
TBD

# License
TBD

# Getting Help
TBD